@@ -4,6 +4,7 @@ import sys
 import pickle
 import webbrowser
 
+import cv2
 import json
 import pandas as pd
 import seaborn as sns
@@ -12,7 +13,7 @@ from matplotlib.backends.backend_qtagg import FigureCanvas
 
 from PyQt5.QtCore import pyqtSignal, Qt, QAbstractTableModel, QDir, QEvent, QItemSelectionModel, QModelIndex, QObject, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, QSortFilterProxyModel, QStringListModel, QUrl
 from PyQt5.QtGui import QColor, QDesktopServices, QFont, QFontMetrics, QIntValidator, QPainter, QPixmap, QPolygon, QPolygonF, QTransform
-from PyQt5.QtWidgets import QAction, QAbstractItemView, QApplication, QComboBox, QCompleter, QDoubleSpinBox, QFileDialog, QFileSystemModel, QFrame, QGridLayout, QHeaderView, QHBoxLayout, QLabel, QListView, QMessageBox, QSpacerItem, QTextEdit, QToolButton, QWidget, QPushButton, QLineEdit, QCheckBox, QVBoxLayout, QRadioButton, QButtonGroup, QScrollArea, QTableView, QToolTip, QTreeView
+from PyQt5.QtWidgets import QAction, QAbstractItemView, QApplication, QComboBox, QCompleter, QDialog, QDialogButtonBox, QDoubleSpinBox, QFileDialog, QFileSystemModel, QFrame, QFormLayout, QGridLayout, QHeaderView, QHBoxLayout, QLabel, QListView, QMessageBox, QSpacerItem, QTextEdit, QToolButton, QWidget, QPushButton, QLineEdit, QCheckBox, QVBoxLayout, QRadioButton, QButtonGroup, QScrollArea, QTableView, QToolTip, QTreeView
 PYQT6 = False
 
 import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
@@ -429,6 +430,57 @@ class _ExperimentOrganizationSelectionModel(QItemSelectionModel):
     return super().select(index, command)
 
 
+class _MultipleInputDialog(QDialog):
+  def __init__(self, parent, width, height):
+    super().__init__(parent)
+
+    self._pixelWidth = QLineEdit()
+    self._pixelWidth.setText(width)
+    self._pixelHeight = QLineEdit()
+    self._pixelHeight.setText(height)
+    self._mmWidth = QLineEdit()
+    self._mmHeight = QLineEdit()
+
+    def updateOKButton():
+      try:
+        all(float(lineEdit.text()) for lineEdit in (self._pixelWidth, self._pixelHeight, self._mmWidth, self._mmHeight))
+        enabled = True
+      except ValueError:
+        enabled = False
+      buttonBox.button(QDialogButtonBox.StandardButton.Ok).setEnabled(enabled)
+    self._pixelWidth.textChanged.connect(updateOKButton)
+    self._pixelHeight.textChanged.connect(updateOKButton)
+    self._mmWidth.textChanged.connect(updateOKButton)
+    self._mmHeight.textChanged.connect(updateOKButton)
+
+    buttonBox = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok | QDialogButtonBox.StandardButton.Cancel);
+
+    layout = QFormLayout(self)
+    layout.addRow("Video width (pixels)", self._pixelWidth)
+    layout.addRow("Video height (pixels)", self._pixelHeight)
+    layout.addRow("Video width (mm)", self._mmWidth)
+    layout.addRow("Video height (mm)", self._mmHeight)
+    layout.addWidget(buttonBox)
+
+    buttonBox.accepted.connect(self.accept)
+    buttonBox.rejected.connect(self.reject)
+    updateOKButton()
+
+  def accept(self):
+    if self.getPixelSize() is None:
+      QMessageBox.critical(self, "Could not calculate pixel size", "The deviation between width and height is too large, please check your inputs.")
+      return
+    super().accept()
+
+  def getPixelSize(self):
+    widthPixelSize = float(self._mmWidth.text()) / float(self._pixelWidth.text())
+    heightPixelSize = float(self._mmHeight.text()) / float(self._pixelHeight.text())
+    ratio = widthPixelSize / heightPixelSize
+    if ratio < 0.9 or ratio > 1.1:
+      return None
+    return (widthPixelSize + heightPixelSize) / 2
+
+
 class CreateExperimentOrganizationExcel(QWidget):
   _POTENTIAL_WELLS_FILENAMES = ("intermediaryWellPosition.txt", "intermediaryWellPositionReloadNoMatterWhat.txt")
 
@@ -485,7 +537,7 @@ class CreateExperimentOrganizationExcel(QWidget):
     openExperimentFolderBtn = QPushButton("Open experiment folder")
     openExperimentFolderBtn.clicked.connect(lambda: QDesktopServices.openUrl(QUrl.fromLocalFile(folderPath)))
     tableButtonsLayout.addWidget(openExperimentFolderBtn, alignment=Qt.AlignmentFlag.AlignLeft)
-    self._runExperimentBtn = util.apply_style(QPushButton("Run analysis"), background_color=util.LIGHT_YELLOW)
+    self._runExperimentBtn = util.apply_style(QPushButton("Run analysis"), background_color=util.DEFAULT_BUTTON_COLOR)
     self._runExperimentBtn.clicked.connect(self._unsavedChangesWarning(lambda *_: self._runExperiment(), forceSave=True))
     tableButtonsLayout.addWidget(self._runExperimentBtn, alignment=Qt.AlignmentFlag.AlignLeft)
     tableButtonsLayout.addStretch()
@@ -506,10 +558,24 @@ class CreateExperimentOrganizationExcel(QWidget):
     self._FPSLineEdit = QLineEdit()
     self._FPSLineEdit.editingFinished.connect(self._FPSChanged)
     videoDetailsLayout.addWidget(self._FPSLineEdit, 0, 1, alignment=Qt.AlignmentFlag.AlignLeft)
-    videoDetailsLayout.addWidget(QLabel("Pixel size:"), 1, 0, alignment=Qt.AlignmentFlag.AlignLeft)
+    videoDetailsLayout.addWidget(QLabel("Pixel size (mm):"), 1, 0, alignment=Qt.AlignmentFlag.AlignLeft)
     self._pixelSizeLineEdit = QLineEdit()
     self._pixelSizeLineEdit.editingFinished.connect(self._pixelSizeChanged)
     videoDetailsLayout.addWidget(self._pixelSizeLineEdit, 1, 1, alignment=Qt.AlignmentFlag.AlignLeft)
+    pixelSizeDialogButton = QPushButton("Calculate pixel size")
+
+    def calculatePixelSize():
+      exampleFrame = self._findExampleFrame(self._shownVideo)
+      if exampleFrame is not None:
+        height, width = map(str, exampleFrame.shape[:2])
+      else:
+        height, width = '', ''
+      dialog = _MultipleInputDialog(controller.window, width, height)
+      dialog.setWindowTitle("Enter video dimensions")
+      if dialog.exec():
+        self._pixelSizeLineEdit.setText("{:.2f}".format(dialog.getPixelSize()))
+    pixelSizeDialogButton.clicked.connect(calculatePixelSize)
+    videoDetailsLayout.addWidget(pixelSizeDialogButton, 1, 2, alignment=Qt.AlignmentFlag.AlignLeft)
     videoDetailsLayout.addWidget(QLabel("Condition:"), 2, 0, alignment=Qt.AlignmentFlag.AlignLeft)
     self._conditionLineEdit = QLineEdit()
     conditionCompleter = QCompleter()
@@ -559,7 +625,7 @@ class CreateExperimentOrganizationExcel(QWidget):
 
     buttonsLayout = QHBoxLayout()
     buttonsLayout.addStretch()
-    startPageBtn = util.apply_style(QPushButton("Go to the start page"), background_color=util.LIGHT_CYAN)
+    startPageBtn = QPushButton("Go to the start page")
     startPageBtn.clicked.connect(self._unsavedChangesWarning(lambda *_: controller.show_frame("StartPage")))
     buttonsLayout.addWidget(startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
     previousParameterResultsBtn = util.apply_style(QPushButton("View previous kinematic parameter analysis results"), background_color=util.LIGHT_YELLOW)
@@ -647,11 +713,13 @@ class CreateExperimentOrganizationExcel(QWidget):
         QMessageBox.critical(self.controller.window, "Could not read well positions", "Well positions file could not be read.")
     return None
 
-  def _findValidationVideo(self, folder):
+  def _findExampleFrame(self, folder):
     expectedName = os.path.join(folder, '%s.avi' % os.path.basename(folder))
-    if os.path.exists(expectedName):
-      return expectedName
-    return next((os.path.join(folder, f) for f in os.listdir(folder) if os.path.isfile(os.path.join(folder, f)) if f.endswith('.avi')), None)
+    validationVideo = expectedName if os.path.exists(expectedName) else next((os.path.join(folder, f) for f in os.listdir(folder) if os.path.isfile(os.path.join(folder, f)) if f.endswith('.avi')), None)
+    if validationVideo is not None:
+      return zzVideoReading.VideoCapture(validationVideo).read()[1]
+    backgroundPath = os.path.join(folder, 'background.png')
+    return cv2.imread(backgroundPath) if os.path.exists(backgroundPath) else None
 
   def _videoSelected(self, rows):
     if not rows:
@@ -671,10 +739,10 @@ class CreateExperimentOrganizationExcel(QWidget):
     newWellLengths = {len(wells) if wells is not None else None for wells in newSelection.values()}
     self._previousSelection = newSelection
     videoToShow = self._table.model().videoPath(rows[0])
-    validationVideo = self._findValidationVideo(videoToShow)
+    exampleFrame = self._findExampleFrame(videoToShow)
     self._wellsSelected()
     if len(rows) > 1:
-      if (newWellLengths == oldWellLengths and self._shownVideo is not None and validationVideo is None == self._findValidationVideo(self._shownVideo) is None) or \
+      if (newWellLengths == oldWellLengths and self._shownVideo is not None and exampleFrame is None == self._findExampleFrame(self._shownVideo) is None) or \
           (len(newWellLengths) > 1 and len(oldWellLengths) > 1):
         return
       if len(newWellLengths) > 1:
@@ -704,7 +772,7 @@ class CreateExperimentOrganizationExcel(QWidget):
       with open(os.path.join(videoToShow, 'configUsed.json')) as f:
         config = json.load(f)
       self._frame.wellShape = 'rectangle' if config.get("wellsAreRectangles", False) or len(config.get("oneWellManuallyChosenTopLeft", '')) or int(config.get("multipleROIsDefinedDuringExecution", 0)) or config.get("noWellDetection", False) or config.get("groupOfMultipleSameSizeAndShapeEquallySpacedWells", False) else 'circle'
-    if validationVideo is None:
+    if exampleFrame is None:
       self._placeholderVideo.setText("Validation video not found. Data must be modified manually in the table.")
       self._placeholderDetail.hide()
       self._placeholderVideo.show()
@@ -713,7 +781,7 @@ class CreateExperimentOrganizationExcel(QWidget):
       self._frame.setOriginalPixmap(None)
     else:
       self._placeholderVideo.hide()
-      self._frame.setOriginalPixmap(QPixmap(util._cvToPixmap(zzVideoReading.VideoCapture(validationVideo).read()[1])))
+      self._frame.setOriginalPixmap(QPixmap(util._cvToPixmap(exampleFrame)))
       self._wellsSelected()
 
   def _findResultsFile(self, path):
@@ -880,14 +948,14 @@ class ChooseDataAnalysisMethod(QWidget):
     layout = QVBoxLayout()
     layout.addWidget(util.apply_style(QLabel("Choose the analysis you want to perform:"), font=controller.title_font), alignment=Qt.AlignmentFlag.AlignCenter)
 
-    self._compareBtn = util.apply_style(QPushButton("Compare populations with kinematic parameters"), background_color=util.LIGHT_YELLOW)
+    self._compareBtn = util.apply_style(QPushButton("Compare populations with kinematic parameters"), background_color=util.DEFAULT_BUTTON_COLOR)
     self._compareBtn.clicked.connect(lambda: controller.show_frame("PopulationComparison"))
     layout.addWidget(self._compareBtn, alignment=Qt.AlignmentFlag.AlignCenter)
-    self._clusterBtn = util.apply_style(QPushButton("Cluster bouts of movements  (for zebrafish only)"), background_color=util.LIGHT_YELLOW)
+    self._clusterBtn = util.apply_style(QPushButton("Cluster bouts of movements  (for zebrafish only)"), background_color=util.DEFAULT_BUTTON_COLOR)
     self._clusterBtn.clicked.connect(lambda: controller.show_frame("BoutClustering"))
     layout.addWidget(self._clusterBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
-    self._startPageBtn = util.apply_style(QPushButton("Go to the start page"), background_color=util.LIGHT_CYAN)
+    self._startPageBtn = QPushButton("Go to the start page")
     self._startPageBtn.clicked.connect(lambda: controller.show_frame("StartPage"))
     layout.addWidget(self._startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
@@ -913,6 +981,7 @@ class PopulationComparison(QWidget):
     self._saveRawDataCheckbox.setVisible(False)  # XXX: hidden from the moment because of a bug, unhide it once it's fixed
     advancedOptionsLayout.addWidget(self._saveRawDataCheckbox, alignment=Qt.AlignmentFlag.AlignCenter)
     self._forcePandasRecreation = QCheckBox("Force recalculation of all parameters even if they have already been calculated and saved.")
+    self._forcePandasRecreation.setChecked(True)
     advancedOptionsLayout.addWidget(self._forcePandasRecreation, alignment=Qt.AlignmentFlag.AlignCenter)
 
     advancedOptionsLayout.addWidget(util.apply_style(QLabel("Number of frames between each frame used for distance calculation (to avoid noise due to close-by subsequent points) (default value is 4):"), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
@@ -930,26 +999,27 @@ class PopulationComparison(QWidget):
     advancedOptionsLayout.addWidget(self._minNbBendForBoutDetect, alignment=Qt.AlignmentFlag.AlignCenter)
 
     advancedOptionsLayout.addWidget(util.apply_style(QLabel("If, for a bout, the tail tracking related kinematic parameters are being discarded because of a low amount of bends,"), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
-    advancedOptionsLayout.addWidget(util.apply_style(QLabel("should the BoutDuration, TotalDistance, Speed and IBI also be discarded for that bout?"), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
-    self._discardRadioButton = QRadioButton("Yes, discard BoutDuration, TotalDistance, Speed and IBI in that situation")
+    advancedOptionsLayout.addWidget(util.apply_style(QLabel("should the Bout Duration (s), Bout Distance (mm), Bout Speed (mm/s) and IBI (s) also be discarded for that bout?"), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
+    self._discardRadioButton = QRadioButton("Yes, discard Bout Duration (s), Bout Distance (mm), Bout Speed (mm/s) and IBI (s) in that situation")
     self._discardRadioButton.setChecked(True)
     advancedOptionsLayout.addWidget(self._discardRadioButton, alignment=Qt.AlignmentFlag.AlignCenter)
-    self._keepRadioButton = QRadioButton("No, keep BoutDuration, TotalDistance, Speed and IBI in that situation")
+    self._keepRadioButton = QRadioButton("No, keep Bout Duration (s), Bout Distance (mm), Bout Speed (mm/s) and IBI (s) in that situation")
     advancedOptionsLayout.addWidget(self._keepRadioButton, alignment=Qt.AlignmentFlag.AlignCenter)
-    advancedOptionsLayout.addWidget(util.apply_style(QLabel("Please ignore the two questions above if you're only looking at BoutDuration, TotalDistance, Speed and IBI."), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
+    advancedOptionsLayout.addWidget(util.apply_style(QLabel("Please ignore the two questions above if you're only looking at Bout Duration (s), Bout Distance (mm), Bout Speed (mm/s) and IBI (s)."), font=QFont("Helvetica", 10)), alignment=Qt.AlignmentFlag.AlignCenter)
 
     self._advancedOptionsExpander = util.Expander(self, "Show advanced options", advancedOptionsLayout)
     layout.addWidget(self._advancedOptionsExpander)
 
-    self._launchBtn = util.apply_style(QPushButton("Launch Analysis"), background_color=util.LIGHT_YELLOW)
+    self._launchBtn = util.apply_style(QPushButton("Launch Analysis"), background_color=util.DEFAULT_BUTTON_COLOR)
     self._launchBtn.clicked.connect(lambda: self._populationComparison(self._tailTrackingParametersCheckbox.isChecked(), self._saveInMatlabFormatCheckbox.isChecked(), self._saveRawDataCheckbox.isChecked(), self._forcePandasRecreation.isChecked(), self._minNbBendForBoutDetect.text(), self._discardRadioButton.isChecked(), self._keepRadioButton.isChecked(), self._frameStepForDistanceCalculation.text()))
     layout.addWidget(self._launchBtn, alignment=Qt.AlignmentFlag.AlignCenter)
-    self._startPageBtn = util.apply_style(QPushButton("Go to the start page"), background_color=util.LIGHT_CYAN)
+    self._startPageBtn = QPushButton("Go to the start page")
     self._startPageBtn.clicked.connect(lambda: controller.show_frame("StartPage"))
     layout.addWidget(self._startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
     self.setLayout(layout)
 
+  @util.showInProgressPage('Parameters calculation')
   def _populationComparison(self, TailTrackingParameters=0, saveInMatlabFormat=0, saveRawData=0, forcePandasRecreation=0, minNbBendForBoutDetect=3, discard=0, keep=1, frameStepForDistanceCalculation='4'):
     if len(frameStepForDistanceCalculation) == 0:
       frameStepForDistanceCalculation = '4'
@@ -1077,10 +1147,10 @@ class BoutClustering(QWidget):
 
     layout.addWidget(util.Expander(self, "Show advanced options", advancedOptionsLayout))
 
-    launchBtn = util.apply_style(QPushButton("Launch Analysis", self), background_color=util.LIGHT_YELLOW)
+    launchBtn = util.apply_style(QPushButton("Launch Analysis", self), background_color=util.DEFAULT_BUTTON_COLOR)
     launchBtn.clicked.connect(lambda: controller.boutClustering(controller, nbClustersToFind.text(), freelySwimmingRadioButton.isChecked(), headEmbeddedRadioButton.isChecked(), minNbBendForBoutDetect.text(), nbVideosToSave.text(), modelUsedForClusteringCheckbox.isChecked(), removeOutliersCheckbox.isChecked(), frameStepForDistanceCalculation.text(), removeBoutsContainingNanValuesInParametersUsedForClustering.isChecked(), self._forcePandasRecreation.isChecked()))
     layout.addWidget(launchBtn, alignment=Qt.AlignmentFlag.AlignCenter)
-    startPageBtn = util.apply_style(QPushButton("Go to the start page", self), background_color=util.LIGHT_CYAN)
+    startPageBtn = QPushButton("Go to the start page", self)
     startPageBtn.clicked.connect(lambda: controller.show_frame("StartPage"))
     layout.addWidget(startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
@@ -1103,7 +1173,7 @@ class AnalysisOutputFolderClustering(QWidget):
     viewRawBtn.clicked.connect(lambda: controller.openAnalysisFolder(controller.homeDirectory, 'data'))
     layout.addWidget(viewRawBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
-    startPageBtn = util.apply_style(QPushButton("Go to the start page", self), background_color=util.LIGHT_CYAN)
+    startPageBtn = QPushButton("Go to the start page", self)
     startPageBtn.clicked.connect(lambda: controller.show_frame("StartPage"))
     layout.addWidget(startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
 
@@ -1261,7 +1331,7 @@ class KinematicParametersVisualization(util.CollapsibleSplitter):
       self._linkBtn = util.apply_style(QPushButton("Video data analysis online documentation"), background_color=util.LIGHT_YELLOW)
       self._linkBtn.clicked.connect(lambda: webbrowser.open_new("https://zebrazoom.org/documentation/docs/behaviorAnalysis/behaviorAnalysisGUI"))
       buttonsLayout.addWidget(self._linkBtn, alignment=Qt.AlignmentFlag.AlignCenter)
-      self._startPageBtn = util.apply_style(QPushButton("Go to the start page"), background_color=util.LIGHT_CYAN)
+      self._startPageBtn = QPushButton("Go to the start page")
       self._startPageBtn.clicked.connect(lambda: app.show_frame("StartPage"))
       buttonsLayout.addWidget(self._startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
       buttonsLayout.addStretch(1)
@@ -1309,7 +1379,8 @@ class KinematicParametersVisualization(util.CollapsibleSplitter):
     self._selectAllCheckbox = util.apply_style(QCheckBox('Select all'), font_weight='bold')
     self._selectAllCheckbox.stateChanged.connect(self._checkOrUncheckAll)
     checkboxesLayout.addWidget(self._selectAllCheckbox, alignment=Qt.AlignmentFlag.AlignLeft)
-    precheckedParams = {'BoutDuration', 'TotalDistance', 'Speed', 'NumberOfOscillations', 'meanTBF', 'maxTailAngleAmplitude'}
+    precheckedParams = {'Bout Duration (s)', 'Bout Distance (mm)', 'Bout Speed (mm/s)', 'Numer of Oscillations', 'meanTBF', 'maxTailAngleAmplitude',
+                        'BoutDuration', 'TotalDistance', 'Speed', 'NumberOfOscillations', 'meanTBF', 'maxTailAngleAmplitude'}  # keep the old names for compatibility
     for param in self._allParameters + self._medianParameters:
       if param in self._paramCheckboxes:
         continue
@@ -1356,7 +1427,7 @@ class KinematicParametersVisualization(util.CollapsibleSplitter):
     self._linkBtn = util.apply_style(QPushButton("Video data analysis online documentation"), background_color=util.LIGHT_YELLOW)
     self._linkBtn.clicked.connect(lambda: webbrowser.open_new("https://zebrazoom.org/documentation/docs/behaviorAnalysis/behaviorAnalysisGUI"))
     buttonsLayout.addWidget(self._linkBtn, alignment=Qt.AlignmentFlag.AlignCenter)
-    self._startPageBtn = util.apply_style(QPushButton("Go to the start page"), background_color=util.LIGHT_CYAN)
+    self._startPageBtn = QPushButton("Go to the start page")
     self._startPageBtn.clicked.connect(lambda: app.show_frame("StartPage"))
     buttonsLayout.addWidget(self._startPageBtn, alignment=Qt.AlignmentFlag.AlignCenter)
     buttonsLayout.addStretch(1)
