@@ -73,7 +73,7 @@ def IsMinOrMax(maxpeaks, minpeaks, val ):
   # return [tailangles_arr, tailangles_arr_smoothed]
 
 
-def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
+def createSuperStruct(dataPerWell, wellPositions, hyperparameters, pathToOriginalVideo=''):
 
   if (hyperparameters["freqAlgoPosFollow"] != 0):
     print("Starting the creation of the super structure")
@@ -149,7 +149,7 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
           minpeaks, properties = find_peaks(-TailAngle_smoothed, prominence=minProminenceForBendsDetect, width=hyperparameters["windowForLocalBendMinMaxFind"])
           
           if (len(minpeaks) + len(maxpeaks) >= hyperparameters["minNbPeaksForBoutDetect"] ):
-          
+            
             ind = 1
             minDiffBetweenSubsequentBendAmp = hyperparameters["minDiffBetweenSubsequentBendAmp"]
             
@@ -220,13 +220,13 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
             item['Bend_Timing'] = []
             item['Bend_TimingAbsolute'] = []
             item['Bend_Amplitude'] = []
-            item['TailAngle_raw'] = []
-            item['TailAngle_smoothed'] = []
+            # item['TailAngle_Raw'] = []
+            # item['TailAngle_smoothed'] = []
             tab[item["AnimalNumber"]].append(item)
           
         else:
-          item['TailAngle_raw'] = []
-          item['TailAngle_smoothed'] = []
+          # item['TailAngle_Raw'] = []
+          # item['TailAngle_smoothed'] = []
           tab[item["AnimalNumber"]].append(item)
       else:
         tab[item["AnimalNumber"]].append(item)
@@ -242,6 +242,9 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
     videoDataResults['videoFPS']    = hyperparameters["videoFPS"]
   if hyperparameters["videoPixelSize"]:
     videoDataResults['videoPixelSize']    = hyperparameters["videoPixelSize"]
+  
+  if hyperparameters['savePathToOriginalVideoForValidationVideo']:
+    videoDataResults['pathToOriginalVideo'] = pathToOriginalVideo
     
   if (hyperparameters["freqAlgoPosFollow"] != 0):
     print("Super Structure created")
