@@ -42,22 +42,36 @@ def visualizeClusters(dfParam, classifications, predictedProbas, modelUsedForClu
       df2 = df2.groupby(['Trial_ID', 'Well_ID', 'Condition']).sum()
       df2['Condition'] = [elem[2] for elem in df2.index]
       df2['totalNbOfBouts'] = df2['classifiedAs0']
-      if nbCluster > 2:
+      if nbCluster >= 2:
         for i in range(1, nbCluster):
           df2['totalNbOfBouts'] = df2['totalNbOfBouts'] + df2['classifiedAs' + str(i)]
+      df2['totalNbOfBouts'] = df2['totalNbOfBouts'].replace(0, 1)
       for i in range(0, nbCluster):
         df2['classifiedAs' + str(i)] = df2['classifiedAs' + str(i)] / df2['totalNbOfBouts']
+      
+      df2.to_excel(os.path.join(outputFolderResult, 'clusterProportionsPerAnimal.xlsx'))
+      
       for idxCond, cond in enumerate(np.unique(dfParam['Condition'].values)):
         for classed in range(0, len(proportions[0])):
-          proportions[idxCond, classed] = np.sum(df2.loc[df2['Condition'] == cond]['classifiedAs' + str(classed)])
+          proportions[idxCond, classed] = np.median(df2.loc[df2['Condition'] == cond]['classifiedAs' + str(classed)])
+      
+      fig, tabAx = plt.subplots(1, len(proportions[0]), figsize=(22.9, 8.8))
+      for classed in range(0, len(proportions[0])):
+        b = sns.boxplot(ax=tabAx[int(classed)], data=df2, x='Condition', y='classifiedAs' + str(classed), showmeans=1, showfliers=1)
+        c = sns.stripplot(ax=tabAx[int(classed)], data=df2, x='Condition', y='classifiedAs' + str(classed), color='red', size=7)
+        b.set_ylabel('', fontsize=0)
+        b.set_xlabel('', fontsize=0)
+        b.axes.set_title('Cluster ' + str(classed), fontsize=30)
+      plt.savefig(os.path.join(outputFolderResult, 'clustersProportionsPerFish.png'))
+      
     else:
+      
       df2 = dfParam[['Condition','classification']]
       for idxCond, cond in enumerate(np.unique(dfParam['Condition'].values)):
         for classed in range(0, len(proportions[0])):
           proportions[idxCond, classed] = len(df2.loc[(df2['Condition'] == cond) & (df2['classification'] == classed)])
-    
-    for i in range(0, nbConditions):
-      proportions[i, :] = proportions[i, :] / sum(proportions[i, :])
+      for i in range(0, nbConditions):
+        proportions[i, :] = proportions[i, :] / sum(proportions[i, :])
     
     if clusterProportionsPerFish:
       outF = open(os.path.join(outputFolderResult, 'proportionsPerFish.txt'), "w")
@@ -390,9 +404,9 @@ def visualizeClusters(dfParam, classifications, predictedProbas, modelUsedForClu
   if globalParametersCalculations:
     
     for plotOutliersAndMean in [0, 1]:
-      globParam1 = ['BoutDuration', 'TotalDistance', 'Speed', 'NumberOfOscillations', 'meanTBF', 'maxTailAngleAmplitude']
-      globParam2 = ['maxOfInstantaneousTBF', 'meanOfInstantaneousTBF', 'medianOfInstantaneousTBF', 'maxBendAmplitude', 'meanBendAmplitude', 'medianBendAmplitude']
-      globParam3 = ['deltaHead', 'firstBendTime', 'firstBendAmplitude', 'IBI', 'xmean', 'ymean']
+      globParam1 = ['BoutDuration', 'Bout Distance (mm)', 'Bout Speed (mm/s)', 'Number of Oscillations', 'meanTBF', 'maxTailAngleAmplitude']
+      globParam2 = ['Max TBF (Hz)', 'Mean TBF (Hz)', 'medianOfInstantaneousTBF', 'Max absolute TBA (deg.)', 'Mean absolute TBA (deg.)', 'Median absolute TBA (deg.)']
+      globParam3 = ['Absolute Yaw (deg)', 'TBA#1 timing (deg)', 'TBA#1 Amplitude (deg)', 'IBI (s)', 'xmean', 'ymean']
       globParam4 = ['binaryClass25degMaxTailAngle', 'BoutFrameNumberStart', 'tailAngleSymmetry', 'secondBendAmpDividedByFirst']
       
       for idxGlobParam, globParam in enumerate([globParam1, globParam2, globParam3, globParam4]):
@@ -413,9 +427,9 @@ def visualizeClusters(dfParam, classifications, predictedProbas, modelUsedForClu
     
     ###
     
-    globParam1 = ['BoutDuration', 'TotalDistance', 'Speed', 'NumberOfOscillations', 'meanTBF', 'maxTailAngleAmplitude']
-    globParam2 = ['maxOfInstantaneousTBF', 'meanOfInstantaneousTBF', 'medianOfInstantaneousTBF', 'maxBendAmplitude', 'meanBendAmplitude', 'medianBendAmplitude']
-    globParam3 = ['deltaHead', 'firstBendTime', 'firstBendAmplitude', 'IBI', 'xmean', 'ymean']
+    globParam1 = ['BoutDuration', 'Bout Distance (mm)', 'Bout Speed (mm/s)', 'Number of Oscillations', 'meanTBF', 'maxTailAngleAmplitude']
+    globParam2 = ['Max TBF (Hz)', 'Mean TBF (Hz)', 'medianOfInstantaneousTBF', 'Max absolute TBA (deg.)', 'Mean absolute TBA (deg.)', 'Median absolute TBA (deg.)']
+    globParam3 = ['Absolute Yaw (deg)', 'TBA#1 timing (deg)', 'TBA#1 Amplitude (deg)', 'IBI (s)', 'xmean', 'ymean']
     globParam4 = ['binaryClass25degMaxTailAngle', 'BoutFrameNumberStart', 'tailAngleSymmetry', 'secondBendAmpDividedByFirst']
     
     for calculateKinematicParametersPerFish in [True, False]:
