@@ -3,7 +3,7 @@ import numpy as np
 from scipy.interpolate import UnivariateSpline
 import math
 
-def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation, previousBoutEnd, listOfParametersToCalculate, firstFrame, lastFrame):
+def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation, previousBoutEnd, listOfParametersToCalculate, firstFrame, lastFrame, minimumFrameToFrameDistanceToBeConsideredAsMoving=0):
   
   listOfParametersCalculated = []
   
@@ -18,7 +18,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'TotalDistance':
+    elif parameterToCalculate == 'Bout Distance (mm)':
       
       TotalDistance = 0
       posX = curbout["HeadX"]
@@ -36,15 +36,42 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
       listOfParametersCalculated.append(TotalDistance)
     
     
-    
-    elif parameterToCalculate == 'Speed':
+    elif parameterToCalculate == 'maxInstantaneousSpeed':
       
-      Speed = TotalDistance / BoutDuration # This is a bit of a "hack" (not very "clean"), it only works because the listOfParametersToCalculate provided contains BoutDuration and TotalDistance before Speed
+      posX = curbout["HeadX"]
+      posY = curbout["HeadY"]
+      instantaneousSpeed = []
+      for j in range(0, len(posX)-1):
+        instantaneousSpeed.append(math.sqrt((posX[j+1] - posX[j])**2 + (posY[j+1] - posY[j])**2) * pixelSize * fps)
+      listOfParametersCalculated.append(np.max(instantaneousSpeed))
+    
+    
+    elif parameterToCalculate == 'percentOfMovingFramesBasedOnDistance':
+      
+      posX = curbout["HeadX"]
+      posY = curbout["HeadY"]
+      # rangeUsedForDistanceCalculation   = [frameStepForDistanceCalculation*i for i in range(0, int(len(posX)/frameStepForDistanceCalculation))]
+      # if len(rangeUsedForDistanceCalculation) == 0:
+        # rangeUsedForDistanceCalculation = [0, len(posX) - 1]
+      # else:
+        # rangeUsedForDistanceCalculation = rangeUsedForDistanceCalculation + [len(posX) - 1]
+      # posX = [posX[i] for i in rangeUsedForDistanceCalculation]
+      # posY = [posY[i] for i in rangeUsedForDistanceCalculation]
+      distance = np.array([math.sqrt((posX[j+1] - posX[j])**2 + (posY[j+1] - posY[j])**2) * pixelSize for j in range(0, len(posX)-1)])
+      numberOfMovingFrames   = int(np.sum(distance > minimumFrameToFrameDistanceToBeConsideredAsMoving))
+      percentOfMovingFrames = (numberOfMovingFrames / (lastFrame - firstFrame + 1)) * 100
+      listOfParametersCalculated.append(percentOfMovingFrames)
+    
+    
+    
+    elif parameterToCalculate == 'Bout Speed (mm/s)':
+      
+      Speed = TotalDistance * fps / (curbout["BoutEnd"] - curbout["BoutStart"]) # This is a bit of a "hack" (not very "clean"), it only works because the listOfParametersToCalculate provided contains TotalDistance before Speed
       listOfParametersCalculated.append(Speed)
     
     
     
-    elif parameterToCalculate == 'NumberOfOscillations':
+    elif parameterToCalculate == 'Number of Oscillations':
       
       if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list:
         NumberOfOscillations = len(curbout["Bend_Timing"]) / 2
@@ -61,7 +88,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'maxOfInstantaneousTBF':
+    elif parameterToCalculate == 'Max TBF (Hz)':
       
       if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list and len(curbout["Bend_Timing"]):
         maxOfInstantaneousTBF = np.max(fps / (2 * np.diff([0] + curbout['Bend_Timing'])))
@@ -71,7 +98,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'meanOfInstantaneousTBF':
+    elif parameterToCalculate == 'Mean TBF (Hz)':
       
       if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list and len(curbout["Bend_Timing"]):
         meanOfInstantaneousTBF = np.mean(fps / (2 * np.diff([0] + curbout['Bend_Timing'])))
@@ -91,7 +118,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'maxBendAmplitude':
+    elif parameterToCalculate == 'Max absolute TBA (deg.)':
       
       if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
         maxBendAmplitude = max(list(map(abs, curbout["Bend_Amplitude"]))) * (180 / math.pi)
@@ -101,17 +128,37 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'medianBendAmplitude':
+    elif parameterToCalculate == 'maxBendAmplitudeSigned':
+      
+      if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
+        maxBendAmplitudeSigned = curbout["Bend_Amplitude"][np.argmax(abs(np.array(curbout["Bend_Amplitude"])))] * (180 / math.pi)
+      else:
+        maxBendAmplitudeSigned = float('NaN')
+      listOfParametersCalculated.append(maxBendAmplitudeSigned)
+    
+    
+    
+    elif parameterToCalculate == 'Median absolute TBA (deg.)':
       
       if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
         medianBendAmplitude = np.median(list(map(abs, curbout["Bend_Amplitude"]))) * (180 / math.pi)
       else:
         medianBendAmplitude = float('NaN')
       listOfParametersCalculated.append(medianBendAmplitude)
-    
-    
-    
-    elif parameterToCalculate == 'meanBendAmplitude':
+
+
+
+    elif parameterToCalculate == 'medianBendAmplitudeSigned':
+      
+      if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
+        medianBendAmplitudeSigned = np.median(curbout["Bend_Amplitude"]) * (180 / math.pi)
+      else:
+        medianBendAmplitudeSigned = float('NaN')
+      listOfParametersCalculated.append(medianBendAmplitudeSigned)
+
+
+
+    elif parameterToCalculate == 'Mean absolute TBA (deg.)':
       
       if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
         meanBendAmplitude = np.mean(list(map(abs, curbout["Bend_Amplitude"]))) * (180 / math.pi)
@@ -145,7 +192,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'deltaHead':
+    elif parameterToCalculate == 'Absolute Yaw (deg)':
       
       deltahead  = abs(getDeltaHead(curbout))
       listOfParametersCalculated.append(deltahead)
@@ -196,7 +243,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'firstBendTime':
+    elif parameterToCalculate == 'TBA#1 timing (deg)':
     
       if "Bend_Timing" in curbout and type(curbout["Bend_Timing"]) == list and len(curbout["Bend_Timing"]):
         firstBendTime = curbout["Bend_Timing"][0] / fps
@@ -206,17 +253,27 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     
     
-    elif parameterToCalculate == 'firstBendAmplitude':
+    elif parameterToCalculate == 'TBA#1 Amplitude (deg)':
       
       if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
         firstBendAmplitude = abs(curbout["Bend_Amplitude"][0]) * (180 / math.pi)
       else:
         firstBendAmplitude = float('NaN')
       listOfParametersCalculated.append(firstBendAmplitude)
-    
-    
-    
-    elif parameterToCalculate == 'IBI':
+
+
+
+    elif parameterToCalculate == 'firstBendAmplitudeSigned':
+      
+      if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]):
+        firstBendAmplitudeSigned = curbout["Bend_Amplitude"][0] * (180 / math.pi)
+      else:
+        firstBendAmplitudeSigned = float('NaN')
+      listOfParametersCalculated.append(firstBendAmplitudeSigned)
+
+
+
+    elif parameterToCalculate == 'IBI (s)':
       
       IBI = (curbout["BoutStart"] - previousBoutEnd) / fps
       listOfParametersCalculated.append(IBI)
@@ -238,12 +295,12 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
           TailAngle = curbout["TailAngle_Raw"]
         else:
           TailAngle = []
-      maxTailAngle = max(TailAngle)
-      minTailAngle = min(TailAngle)
+      maxTailAngle = max(TailAngle) if len(TailAngle) else 0
+      minTailAngle = min(TailAngle) if len(TailAngle) else 0
       if abs(maxTailAngle) < abs(minTailAngle):
         TailAngle = [-elem for elem in TailAngle]
-      maxTailAngle = max(TailAngle)
-      minTailAngle = min(TailAngle)
+      maxTailAngle = max(TailAngle) if len(TailAngle) else 0
+      minTailAngle = min(TailAngle) if len(TailAngle) else 0
       tailAngleSymmetry = - minTailAngle / maxTailAngle if maxTailAngle > 0 else 1
       # = 1 if perfect symetry OR if tail angle staying constant and always at 0
       # = 0 if tail beating only on one side, starting from the 0 position
@@ -254,7 +311,7 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
     
     elif parameterToCalculate == 'secondBendAmpDividedByFirst':
       
-      if len(curbout["Bend_Amplitude"]) >= 2 and curbout["Bend_Amplitude"][0]:
+      if "Bend_Amplitude" in curbout and type(curbout["Bend_Amplitude"]) == list and len(curbout["Bend_Amplitude"]) >= 2 and curbout["Bend_Amplitude"][0]:
         secondBendAmpDividedByFirst = curbout["Bend_Amplitude"][1] / curbout["Bend_Amplitude"][0]
       else:
         secondBendAmpDividedByFirst = float('Nan')
@@ -272,9 +329,22 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
         else:
           tailAngleIntegral = float('NaN')
       listOfParametersCalculated.append(tailAngleIntegral)
-    
-    
-    
+
+
+
+    elif parameterToCalculate == 'tailAngleIntegralSigned':
+      
+      if "TailAngle_smoothed" in curbout and len(curbout["TailAngle_smoothed"]):
+        tailAngleIntegral = np.sum([ta for ta in curbout["TailAngle_smoothed"]]) * (180 / math.pi)
+      else:
+        if "TailAngle_Raw" in curbout and len(curbout["TailAngle_Raw"]):
+          tailAngleIntegral = np.sum([ta for ta in curbout["TailAngle_Raw"]]) * (180 / math.pi) # Maybe this value should be "reduced" in some way to be consistent with the previous smoothed tail angle
+        else:
+          tailAngleIntegral = float('NaN')
+      listOfParametersCalculated.append(tailAngleIntegral)
+
+
+
     else:
       
       print("The parameter", parameterToCalculate, "is not specified")
