@@ -118,7 +118,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv, useGUI=True):
     outfile.close()
   else:
     # Creating output folder
-    if not(hyperparameters["reloadWellPositions"]) and not(hyperparameters["reloadBackground"]) and not(os.path.exists(os.path.join(outputFolderVideo, 'intermediaryWellPositionReloadNoMatterWhat.txt'))) and not(hyperparameters["dontDeleteOutputFolderIfAlreadyExist"]):
+    if not(hyperparameters["reloadWellPositions"]) and not(hyperparameters["reloadBackground"]) and not(os.path.exists(os.path.join(outputFolderVideo, 'intermediaryWellPositionReloadNoMatterWhat.txt'))) and not os.path.exists(os.path.join(outputFolderVideo, 'rotationAngle.txt')) and not(hyperparameters["dontDeleteOutputFolderIfAlreadyExist"]):
       if os.path.exists(outputFolderVideo):
         if glob.glob(os.path.join(outputFolderVideo, 'results_*.txt')) and glob.glob(os.path.join(outputFolderVideo, '*.avi')):
           pastNumbersTaken = 1
@@ -156,6 +156,11 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv, useGUI=True):
     wellPositions = [{"topLeftX":0, "topLeftY":0, "lengthX": hyperparameters["videoWidth"], "lengthY": hyperparameters["videoHeight"]}]
   else:
     print("start find wells")
+    if hyperparameters["groupOfMultipleSameSizeAndShapeEquallySpacedWells"] and not hyperparameters["exitAfterBackgroundExtraction"]:
+      rotationAngleFile = os.path.join(outputFolderVideo, 'rotationAngle.txt')
+      if os.path.exists(rotationAngleFile):
+        with open(rotationAngleFile, 'rb') as f:
+          hyperparameters.update(pickle.load(f))
     if hyperparameters["saveWellPositionsToBeReloadedNoMatterWhat"]:
       outfile = open(os.path.join(outputFolderVideo, 'intermediaryWellPositionReloadNoMatterWhat.txt'),'wb')
       wellPositions = findWells(os.path.join(pathToVideo, videoNameWithExt), hyperparameters)
@@ -240,7 +245,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv, useGUI=True):
     processes = -1
     output2 = fasterMultiprocessing2(os.path.join(pathToVideo, videoNameWithExt), background, wellPositions, [], hyperparameters, videoName)
   else:
-    if globalVariables["noMultiprocessing"] == 0:
+    if globalVariables["noMultiprocessing"] == 0 and not hyperparameters['headEmbeded']:
       if hyperparameters["onlyTrackThisOneWell"] == -1:
         # for all wells, in parallel
         processes = []
@@ -271,7 +276,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv, useGUI=True):
   for data in dataPerWellUnsorted:
     paramDataPerWell[data[0]]    = data[1]
     trackingDataPerWell[data[0]] = data[2]
-  if processes != -1 and hyperparameters["onlyTrackThisOneWell"] == -1 and globalVariables["noMultiprocessing"] == 0:
+  if processes != -1 and hyperparameters["onlyTrackThisOneWell"] == -1 and (globalVariables["noMultiprocessing"] == 0 and not hyperparameters['headEmbeded']):
     for p in processes:
       p.join()
   if (hyperparameters["freqAlgoPosFollow"] != 0):
@@ -287,14 +292,15 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv, useGUI=True):
     
   if hyperparameters["debugPauseBetweenTrackAndParamExtract"] != "justSaveTrackData":
     # Creating super structure
-    superStruct = createSuperStruct(paramDataPerWell, wellPositions, hyperparameters)
+    superStruct = createSuperStruct(paramDataPerWell, wellPositions, hyperparameters, os.path.join(pathToVideo, videoNameWithExt))
   
     # Creating validation video
-    if hyperparameters["copyOriginalVideoToOutputFolderForValidation"]:
-      shutil.copyfile(os.path.join(pathToVideo, videoNameWithExt), os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'originalVideoWithoutAnyTrackingDisplayed_pleaseUseTheGUIToVisualizeTrackingPoints.avi'))
-    else:
-      if hyperparameters["createValidationVideo"]:
-        infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
+    if not(hyperparameters["savePathToOriginalVideoForValidationVideo"]):
+      if hyperparameters["copyOriginalVideoToOutputFolderForValidation"]:
+        shutil.copyfile(os.path.join(pathToVideo, videoNameWithExt), os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'originalVideoWithoutAnyTrackingDisplayed_pleaseUseTheGUIToVisualizeTrackingPoints.avi'))
+      else:
+        if hyperparameters["createValidationVideo"]:
+          infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
     
     # Various post-processing options depending on configuration file choices
     superStruct = dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName, videoExt)
